@@ -6,7 +6,7 @@ use warnings;
 use XSLoader;
 use parent 'Exporter';
 
-our $VERSION = '0.000006';
+our $VERSION = '0.000007';
 XSLoader::load( 'URI::XSEscape', $VERSION );
 
 our @EXPORT_OK = qw{
@@ -24,15 +24,18 @@ sub uri_escape_utf8 {
     return uri_escape($text, $more);
 }
 
-# TODO: check if this is how we overwrite URI::Escape methods
+eval {
+    # ENV{'PERL_URI_XSESCAPE'} = undef # yes
+    # ENV{'PERL_URI_XSESCAPE'} = 1     # yes
+    # ENV{'PERL_URI_XSESCAPE'} = 0     # no
+    if ( ! defined $ENV{'PERL_URI_XSESCAPE'} || $ENV{'PERL_URI_XSESCAPE'} ) {
+        require URI::Escape;
 
-# eval {
-#     require URI::Escape;
-#
-#     *URI::Escape::uri_escape           = *URI::XSEscape::uri_escape;
-#     *URI::Escape::uri_escape_utf8      = *URI::XSEscape::uri_escape_utf8;
-#     *URI::Escape::uri_unescape         = *URI::XSEscape::uri_unescape;
-# };
+        *URI::Escape::uri_escape           = *URI::XSEscape::uri_escape;
+        *URI::Escape::uri_escape_utf8      = *URI::XSEscape::uri_escape_utf8;
+        *URI::Escape::uri_unescape         = *URI::XSEscape::uri_unescape;
+    }
+};
 
 1;
 
@@ -48,7 +51,7 @@ URI::XSEscape - Fast XS URI-escaping library, replacing URI::Escape.
 
 =head1 VERSION
 
-Version 0.000006
+Version 0.000007
 
 =head1 SYNOPSIS
 
@@ -85,7 +88,7 @@ argument, and calling uri_unescape, URI::XSEscape runs between
 25 and 34 times faster than URI::Escape. The other cases are also
 faster, but the difference is not that noticeable.
 
-    $ perl -Iblib/lib -Iblib/arch tools/bench.pl
+    $ PERL_URI_XSESCAPE=0 perl -Iblib/lib -Iblib/arch tools/bench.pl
     URI::Escape 3.31 / URI::Escape::XS 0.13 / URI::XSEscape 0.000004
     -- uri_escape
                         Rate     URI::Escape URI::Escape::XS   URI::XSEscape
@@ -111,9 +114,9 @@ faster, but the difference is not that noticeable.
     URI::XSEscape 1098901/s         2612%            --
 
     -- uri_unescape
-                        Rate     URI::Escape URI::XS::Escape   URI::XSEscape
+                        Rate     URI::Escape URI::Escape::XS   URI::XSEscape
     URI::Escape       74019/s              --            -93%            -96%
-    URI::XS::Escape 1086957/s           1368%              --            -43%
+    URI::Escape::XS 1086957/s           1368%              --            -43%
     URI::XSEscape   1923077/s           2498%             77%              --
 
 =head1 AUTHORS
@@ -122,6 +125,8 @@ faster, but the difference is not that noticeable.
 
 =item * Gonzalo Diethelm C<< gonzus AT cpan DOT org >>
 
+=item * Sawyer X C<< xsawyerx AT cpan DOT org >>
+
 =back
 
 =head1 THANKS
@@ -130,10 +135,6 @@ faster, but the difference is not that noticeable.
 
 =item * Brian Fraser
 
-=item * Sawyer X C<< xsawyerx AT cpan DOT org >>
-
 =item * p5pclub
 
 =back
-
-__END__
